﻿/**
 * @file HolmesServices
 * @author wumingdan
 * @since 2018-08-23
 */

/* global compareVersions */

const HolmesServices = Object.freeze({

    isUnsentLog: (log) => {
        const u = log.u;

        // 含有 u 参数，并且不是 js api log
        // FIXME，目前无法完全准确的判断出是否是补发的请求
        //        当前逻辑存在问题，例如当被补发的请求本身确实就是 js api 时就无法准备判断了
        return u !== undefined && !HolmesServices.isJSAPILog(log);
    },

    isJSAPILog: (log) => {
        const api = log.api;

        return api !== undefined;
    },

    encodeHTML: (html) => {
        return String(html)
            .replace(/&/g, '&amp;')
            .replace(/</g, '&lt;')
            .replace(/>/g, '&gt;')
            .replace(/"/g, '&quot;')
            .replace(/'/g, '&#39;')
            .replace(/ /g, '&nbsp;');
    },

    formatTime: (second, type) => {
        let dd;
        let hh;
        let mm;
        let ss;
        let result;
        if (second === '--') {
            return second;
        }

        if (type === 2) {
            // 时间的另一种表示法： 22'11"
            mm = second / 60 | 0;
            ss = Math.round(second) - mm * 60;
            let ret = '';
            if (mm) {
                ret += mm + '&#039;';
            }
            ret += ss + '&quot;';
            return ret;
        }

        // 先处理天
        dd = second / (24 * 3600) | 0;
        second = Math.round(second) - dd * 24 * 3600;
        // 接着是小时
        hh = second / 3600 | 0;
        second = Math.round(second) - hh * 3600;
        // 之后是分
        mm = second / 60 | 0;
        // 最后是秒
        ss = Math.round(second) - mm * 60;

        if (Math.round(dd) < 10) {
            dd = dd > 0 ? '0' + dd : '';
        }
        if (Math.round(hh) < 10) {
            hh = '0' + hh;
        }
        if (Math.round(mm) < 10) {
            mm = '0' + mm;
        }
        if (Math.round(ss) < 10) {
            ss = '0' + ss;
        }
        if (dd) {
            result = dd + ' ' + hh + ':' + mm + ':' + ss;
        } else {
            result = hh + ':' + mm + ':' + ss;
        }
        return result;
    },

    checkoutVersion: (version, successCb, failedCb) => {
        $.ajax({
            method: 'get',
            url: 'https://tongji.baidu.com/static/tongji/hm-debugger/configs.json?timestamp=' + new Date().getTime(),
            dataType: 'json',
            headers: {
                'X-Requested-With': 'XMLHttpRequest'
            }
        })
        .done(function (data, textStatus, jqXHR) {
            // https://www.npmjs.com/package/compare-versions
            successCb(compareVersions(version, data.version));
        })
        .fail(function (jqXHR, textStatus, errorThrown) {
            console.log('error');
            failedCb();
        });
    }

});
